DirectedGraph

Trait DirectedGraph 

pub trait DirectedGraph:
    EdgeEndpointGraph
    + OutgoingGraph
    + IncomingGraph { }
Convenience marker bundling endpoint resolution and both traversal directions. One-direction layouts should implement the smaller capability traits they can provide instead.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors