pub trait EndpointIndex: IncidenceIndex {
// Provided methods
fn endpoint_bound(&self) -> usize { ... }
fn endpoint_index(&self, endpoint: Self::IncidenceId) -> usize { ... }
}Expand description
Dense endpoint-index capability for graph views with incidences.
Graph-facing name for IncidenceIndex.
Provided Methods
Sourcefn endpoint_bound(&self) -> usize
fn endpoint_bound(&self) -> usize
Returns the exclusive upper bound for endpoint indexes in this graph view.
Sourcefn endpoint_index(&self, endpoint: Self::IncidenceId) -> usize
fn endpoint_index(&self, endpoint: Self::IncidenceId) -> usize
Returns the dense index for endpoint in this graph view.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".