EndpointId

Type Alias EndpointId 

pub type EndpointId<G> = <G as IncidenceBase>::IncidenceId;
Graph-facing alias for a topology incidence ID (binary graph endpoint).

A binary graph endpoint participation is represented as a topology incidence only when a graph view exposes incidence capabilities.