pub type EndpointRole<G> = <G as IncidenceBase>::Role;Expand description
Graph-facing alias for a topology role used to distinguish source and target endpoint participation on graph views that expose incidences.
pub type EndpointRole<G> = <G as IncidenceBase>::Role;Graph-facing alias for a topology role used to distinguish source and target endpoint participation on graph views that expose incidences.