pub trait EdgeIndex: RelationIndex {
// Provided methods
fn edge_bound(&self) -> usize { ... }
fn edge_index(&self, edge: Self::RelationId) -> usize { ... }
}Expand description
Dense edge-index capability for graph views.
Graph-facing name for RelationIndex.
Provided Methods
Sourcefn edge_bound(&self) -> usize
fn edge_bound(&self) -> usize
Returns the exclusive upper bound for edge indexes in this graph view.
Sourcefn edge_index(&self, edge: Self::RelationId) -> usize
fn edge_index(&self, edge: Self::RelationId) -> usize
Returns the dense index for edge in this graph view.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".