EndpointIndex

Trait EndpointIndex 

pub trait EndpointIndex: IncidenceIndex {
    // Provided methods
    fn endpoint_bound(&self) -> usize { ... }
    fn endpoint_index(&self, endpoint: Self::IncidenceId) -> usize { ... }
}
Dense endpoint-index capability for graph views with incidences.

Graph-facing name for IncidenceIndex.

Provided Methods

fn endpoint_bound(&self) -> usize

Returns the exclusive upper bound for endpoint indexes in this graph view.

fn endpoint_index(&self, endpoint: Self::IncidenceId) -> usize

Returns the dense index for endpoint in this graph view.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> EndpointIndex for T
where T: IncidenceIndex,