GraphCounts

Trait GraphCounts 

pub trait GraphCounts: TopologyCounts {
    // Provided methods
    fn node_count(&self) -> usize { ... }
    fn edge_count(&self) -> usize { ... }
}
Count capability for a graph view.

Graph-facing name for TopologyCounts.

Provided Methods

fn node_count(&self) -> usize

Returns the number of nodes visible in this graph view.

fn edge_count(&self) -> usize

Returns the number of edges visible in this graph view.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors