LocalRelationIdentity

Trait LocalRelationIdentity 

pub trait LocalRelationIdentity: CanonicalRelationIdentity {
    // Required method
    fn local_relation_id(
        &self,
        canonical: Self::CanonicalRelationId,
    ) -> Option<Self::RelationId>;
}
Optional canonical-to-local relation identity capability.

This reverse lookup is separate from CanonicalRelationIdentity because it may require extra memory or may be partial for filtered and projected views.

Performance

Lookup should be O(1) unless an implementation documents a weaker contract.

Required Methods

fn local_relation_id( &self, canonical: Self::CanonicalRelationId, ) -> Option<Self::RelationId>

Returns the visible local relation for canonical, if present.

Performance

Expected O(1) unless the implementation documents otherwise.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors