pub type EndpointId<G> = <G as IncidenceBase>::IncidenceId;Expand description
Graph-facing alias for a topology incidence ID (binary graph endpoint).
A binary graph endpoint participation is represented as a topology incidence only when a graph view exposes incidence capabilities.